@@ -310,7 +310,8 @@ class InventoryLine(ModelSQL, ModelView):
             },
         depends=_depends)
     inventory_state = fields.Function(
-        fields.Selection(INVENTORY_STATES, 'Inventory State'),
+        fields.Selection(INVENTORY_STATES, 'Inventory State',
+        depends=['inventory']),
         'on_change_with_inventory_state')
 
     @classmethod
